<?php 

/*-----------------------------------------------------------------------------------

TABLE OF CONTENTS

- Add custom styling to HEAD
- Add custom typograhpy to HEAD
- Add layout to body_class output

-----------------------------------------------------------------------------------*/

add_action('woo_head','woo_ie_head');					// Add IE coniditional code to header

remove_action('wp_head', 'woothemes_wp_head');			// Output stylesheet and custom.css before custom styling
add_action('woo_head', 'woothemes_wp_head');			// Output stylesheet and custom.css before custom styling

add_action('woo_head','woo_custom_styling');			// Add custom styling to HEAD
add_action('woo_head','woo_custom_typography');			// Add custom typography to HEAD
add_filter('body_class','woo_layout_body_class');		// Add layout to body_class output


/*-----------------------------------------------------------------------------------*/
/* Add IE coniditional code to header */
/*-----------------------------------------------------------------------------------*/
if (!function_exists('woo_ie_head')) {
	function woo_ie_head() {
?>
<!--[if lt IE 7]>
<script src="http://ie7-js.googlecode.com/svn/version/2.0(beta3)/IE7.js" type="text/javascript"></script>
<script type="text/javascript" src="<?php bloginfo('template_directory'); ?>/includes/js/pngfix.js"></script>
<script type="text/javascript" src="<?php bloginfo('template_directory'); ?>/includes/js/suckerfish.js"></script>	
<![endif]-->
<?php
	}
}
/*-----------------------------------------------------------------------------------*/
/* Add Custom Styling to HEAD */
/*-----------------------------------------------------------------------------------*/
if (!function_exists('woo_custom_styling')) {
	function woo_custom_styling() {
	
		global $woo_options;
		
		$output = '';
		// Get options
		$body_color = $woo_options['woo_body_color'];
		$body_img = $woo_options['woo_body_img'];
		$body_repeat = $woo_options['woo_body_repeat'];
		$body_position = $woo_options['woo_body_pos'];
		$link = $woo_options['woo_link_color'];
		$hover = $woo_options['woo_link_hover_color'];
		$button = $woo_options['woo_button_color'];
		
		$header_top = $woo_options['woo_header_top_color'];
		$header_color = $woo_options['woo_header_color'];
		$header_bg = $woo_options['woo_header_img'];
		$header_repeat = $woo_options['woo_header_repeat'];
		$header_position = $woo_options['woo_header_pos'];
			
		$footer_widgets = $woo_options['woo_footer_widgets_color'];
		$footer = $woo_options['woo_footer_color'];

		// Add CSS to output
		if ($body_color)
			$output .= '#background {background:'.$body_color.'}' . "\n";
			
		if ($body_img)
			$output .= '#background {background-image:url('.$body_img.')}' . "\n";

		if ($body_img && $body_repeat && $body_position)
			$output .= '#background {background-repeat:'.$body_repeat.'}' . "\n";

		if ($body_img && $body_position)
			$output .= '#background {background-position:'.$body_position.'}' . "\n";

		if ($link)
			$output .= 'a, #top .subscribe a {color:'.$link.'}' . "\n";

		if ($hover)
			$output .= 'a:hover, .post-more a:hover, .post-meta a:hover, .post p.tags a:hover, #top .subscribe a:hover {color:'.$hover.'}' . "\n";

		if ($button) {
			$output .= 'a.button, a.comment-reply-link, #commentform #submit, .submit {background:'.$button.';border-color:'.$button.'}' . "\n";
			$output .= 'a.button:hover, a.button.hover, a.button.active, a.comment-reply-link:hover, #commentform #submit:hover, .submit:hover {background:'.$button.';opacity:0.9;}' . "\n";
		}
		
		if ($header_top)
			$output .= '#top {background:'.$header_top.';border-bottom:1px solid rgba(0,0,0,.2);}' . "\n";
			
		if ($header_color)
			$output .= '#header {background:'.$header_color.';border-top:1px solid rgba(255,255,255,.3);}' . "\n";

		if ($header_bg)
			$output .= '#header {background-image:url('.$header_bg.');border-top:1px solid rgba(255,255,255,.3);}' . "\n";

		if ($header_bg && $header_repeat && $header_position)
			$output .= '#header {background-repeat:'.$header_repeat.'}' . "\n";

		if ($header_bg && $header_position)
			$output .= '#header {background-position:'.$header_position.'}' . "\n";

		if ($footer_widgets)
			$output .= '#footer-widgets {background:'.$footer_widgets.';border-top:1px solid rgba(0,0,0,.2);border-bottom:0;}' . "\n";

		if ($footer)
			$output .= '#footer {background:'.$footer.';border-top:1px solid rgba(0,0,0,.2);} body {background:'.$footer.';}' . "\n";

		// Output styles
		if (isset($output) && $output != '') {
			$output = strip_tags($output);
			$output = "<!-- Woo Custom Styling -->\n<style type=\"text/css\">\n" . $output . "</style>\n";
			echo $output;
		}
			
	}
} 

/*-----------------------------------------------------------------------------------*/
/* Add custom typograhpy to HEAD */
/*-----------------------------------------------------------------------------------*/
if (!function_exists('woo_custom_typography')) {
	function woo_custom_typography() {
	
		// Get options
		global $woo_options;
				
		// Reset	
		$output = '';
		
		// Add Text title and tagline if text title option is enabled
		if ( $woo_options['woo_texttitle'] == "true" ) {		
			
			if ( $woo_options['woo_font_site_title'] )
				$output .= '#logo .site-title a {'.woo_generate_font_css($woo_options['woo_font_site_title']).'}' . "\n";	
			if ( $woo_options['woo_font_tagline'] )
				$output .= '#logo .site-description {'.woo_generate_font_css($woo_options['woo_font_tagline']).'}' . "\n";	
		}

		if ( $woo_options['woo_typography'] == "true") {
			
			if ( $woo_options['woo_font_body'] )
				$output .= 'body { '.woo_generate_font_css($woo_options['woo_font_body'], '1').' }' . "\n";	

			if ( $woo_options['woo_font_nav_top'] )
				$output .= '#top, #top a { '.woo_generate_font_css($woo_options['woo_font_nav_top'], '3').' }' . "\n";	

			if ( $woo_options['woo_font_nav'] )
				$output .= '#topmenu, #topmenu ul li a { '.woo_generate_font_css($woo_options['woo_font_nav'], '1.4').' }' . "\n";	

			if ( $woo_options['woo_font_post_title'] )
				$output .= '.post .title a { '.woo_generate_font_css($woo_options['woo_font_post_title']).' }' . "\n";	
		
			if ( $woo_options['woo_font_post_meta'] )
				$output .= '.post .date-comments { '.woo_generate_font_css($woo_options['woo_font_post_meta']).' }' . "\n";	

			if ( $woo_options['woo_font_post_entry'] )
				$output .= '.entry, .entry p { '.woo_generate_font_css($woo_options['woo_font_post_entry'], '1.5').' } h1, h2, h3, h4, h5, h6 { font-family:'.stripslashes($woo_options['woo_font_post_entry']['face'] ).'; line-height:1.2; }'  . "\n";	

			if ( $woo_options['woo_font_widget_titles'] )
				$output .= '.widget h3 { '.woo_generate_font_css($woo_options['woo_font_widget_titles']).' }'  . "\n";	

		// Add default typography Google Font
		} else {
			
			// Add to $woo_options so woo_google_webfonts() adds javascript		
			$woo_options['woo_default_face'] = array('face' => 'Droid Serif');
			$output .= 'h1, h2, h3, h4, h5, h6 { '.woo_generate_font_css($woo_options['woo_default_face']).' }' . "\n";			

		}
		
		// Output styles
		if (isset($output) && $output != '') {
		
			// Enable Google Fonts stylesheet in HEAD
			if (function_exists('woo_google_webfonts')) woo_google_webfonts();
			
			$output = "\n<!-- Woo Custom Typography -->\n<style type=\"text/css\">\n" . $output . "</style>\n";
			echo $output;
			
		}
			
	}
} 

if (!function_exists('woo_generate_font_css')) {
	// Returns proper font css output
	function woo_generate_font_css($option, $em = '1') {
	
		if (!$option["style"] && !$option["size"] && !$option["unit"] && !$option["color"])
			return 'font-family:'.stripslashes($option["face"]).', serif;'; 
		else
			return 'font:'.$option["style"].' '.$option["size"].$option["unit"].'/'.$em.'em '.stripslashes($option["face"]).';color:'.$option["color"].';';
			
	}
}


/*-----------------------------------------------------------------------------------*/
/* Add layout to body_class output */
/*-----------------------------------------------------------------------------------*/
if (!function_exists('woo_layout_body_class')) {
	function woo_layout_body_class($classes) {
		
		global $woo_options;
		$layout = $woo_options['woo_site_layout'];

		// Set main layout on post or page
		if ( is_singular() ) {
			global $post;
			$single = get_post_meta($post->ID, '_layout', true);
			if ( $single != "" AND $single != "layout-default" ) 
				$layout = $single;
		}
		
		// Add layout to $woo_options array for use in theme
		$woo_options['woo_layout'] = $layout;
		
		// Add classes to body_class() output 
		$classes[] = $layout;
		return $classes;						
					
	}
}



/*-----------------------------------------------------------------------------------*/
/* END */
/*-----------------------------------------------------------------------------------*/
?>